@@ -17,17 +17,19 @@ alfa.profile <- function(x, a = seq(-1, 1, by = 0.01) ) {
   qa <- numeric( length(a) )  ## the log-likelihood values will be stored here
   ja <- sum( log(x) )  ## part of the Jacobian of the alpha transformation
   con <-  - n/2 * d * log(2 * pi * f) - (n - 1) * d/2 + n * (d + 0.5) * log(D) + (a - 1) * ja
+  
   for ( i in 1:length(a) ) {
     trans <- Compositional::alfa( x, a[i] )
     aff <- trans$aff  ## the alpha-transformation
     qa[i] <-  - n/2 * log( abs( det( cov(aff) ) ) ) - D * trans$sa
   }
   qa <- qa + con
+  
   ## the green lines show a 95% CI for the true value of
   ## alpha using a chi-square distribution
   b <- max(qa) - qchisq(0.95, 1)/2
   plot(a, qa, type = "l", xlab = expression( paste(alpha, " values", sep = "") ),
-  ylab = "Profile log-likelihood")
+  ylab = "Profile log-likelihood", cex.axis = 1.2, cex.lab = 1.2)
   abline(h = b, col = 2)
   ci <- c( min(a[qa >= b]), max(a[qa >= b]) )
   names(ci) <- paste(c("2.5", "97.5"), "%", sep = "")
