@@ -1,8 +1,10 @@
 fp <- function(x, lambda) {
-  if ( lambda != 0 ){
+
+  if ( abs(lambda) > 1e-9 ) {
     y <- x[, -1]^lambda - x[, 1]^lambda
   } else {
     y <- Rfast::Log(x[, -1] / x[, 1])
   }
+
   y
 }
