@@ -6,6 +6,6 @@ lcreg.aov <- function(mod0, mod1) {
   stat <- (sse0 - sse1) / ( sse1 / (n - p) )
   pvalue <- pf(stat, 1, n - p, lower.tail = FALSE)
   res <- c(stat, pvalue)
-  names(res) <- c( "F-statistic", "p-value" )
+  names(res) <- c( "F statistic", "p-value" )
   res
 }
